import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

const sectionColors = [
  '#7ECC49','#DB4035','#4073FF','#E05194','#FAD000','#808080','#96c3EB','#B8255F','#158FAD'
  //'LIME GREEN','RED','BLUE','MAGENTA','YELLOW','CHARCOAL','LIGHT BLUE','BERRY RED','TEAL'
		  ]; // representation of countries in different colors
// from github dataset Url made raw
const csvUrl = 'https://gist.githubusercontent.com/Swathireddy05/2fa25010d4f43d2c6e540c0967f98011/raw/99c3c5be6586cd1b9bf44805b886a8468bd19b15/Heartpatients.csv';
//fetching data from dataset
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

const xAxisTickFormat = number =>
  	format('.4~g')(number);

const render = (data, total) => {
  const pieData = pie().value(d=>d.Deathcases)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  //arc
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Deathcases));
  //section label
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Deathcases/1000))+"K")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  //legends
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Deathcases));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.country_name);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Deathcases/1000))+"K");
}

const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Deathcases = +d.Deathcases;
    total += d.Deathcases
  });
	render(data,total);
};
run();